==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/deliveryServices/jobs/new/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.deliveryServices.jobs.new', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.deliveryServices.jobs.new', {
				url: '/new',
				views: {
					deliveryServiceJobsContent: {
						templateUrl: 'common/modules/form/deliveryServiceJob/form.deliveryServiceJob.tpl.html',
						controller: 'FormNewDeliveryServiceJobController',
						resolve: {
							deliveryService: function($stateParams, deliveryServiceService) {
								return deliveryServiceService.getDeliveryService($stateParams.deliveryServiceId);
							},
							job: function($stateParams) {
								return { dsId: $stateParams.deliveryServiceId, startTime: moment().utc().format('YYYY-MM-DD HH:mm:ss') };
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_portal/app/src/modules/private/deliveryServices/jobs/new/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.deliveryServices.jobs.new', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.deliveryServices.jobs.new', {
				url: '/new',
				views: {
					deliveryServiceJobsContent: {
						templateUrl: 'common/modules/form/deliveryServiceJob/form.deliveryServiceJob.tpl.html',
						controller: 'FormNewDeliveryServiceJobController',
						resolve: {
							deliveryService: function($stateParams, deliveryServiceService) {
								return deliveryServiceService.getDeliveryService($stateParams.deliveryServiceId);
							},
							job: function($stateParams) {
								return { dsId: parseInt($stateParams.deliveryServiceId, 10), startTime: moment().utc().format('YYYY-MM-DD HH:mm:ss') };
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
